# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`limits`](#limits): Generates an etc limits file for each entry in array_limits.

### Defined types

* [`limits::file`](#limitsfile): Defines a limit file containing one or more entries

### Data types

* [`Limits::Entry`](#limitsentry): Defines a limit entry for a specific domain
* [`Limits::FileDefinition`](#limitsfiledefinition): Defines a limit file containing one or more entries
* [`Limits::Item`](#limitsitem): List of valid items to specify in /etc/security/limits.conf

## Classes

### <a name="limits"></a>`limits`

Generates an etc limits file for each entry in array_limits.

#### Parameters

The following parameters are available in the `limits` class:

* [`dir_limits`](#dir_limits)
* [`array_limits`](#array_limits)

##### <a name="dir_limits"></a>`dir_limits`

Data type: `Stdlib::AbsolutePath`

Path to the limits.d configuration directory in which each limit file will
be created

Default value: `'/etc/security/limits.d'`

##### <a name="array_limits"></a>`array_limits`

Data type: `Array[Limits::FileDefinition]`

Array of limits file entries. Each corresponds to a separate entity in
$dir_limits and will contain one or more entries. See the Limits::File type
definition for further details.

Default value: `[]`

## Defined types

### <a name="limitsfile"></a>`limits::file`

Defines a limit file containing one or more entries

#### Examples

##### Full definition

```puppet
limits::file { 'snaplogic_limits':
  sequence       => '10',
  header_comment => [
    'Prevents errors when higher pipeline loads execute.',
    'See https://docs-snaplogic.atlassian.net/wiki/spaces/SD/pages/1438367/Installing+a+Snaplex+on+Linux',
  ],
  entries        => {
    'snapuser' => [
      {
        'item'  => 'nproc',
        'type'  => 'soft',
        'value' => '8192',
      },
      {
        'item'  => 'nproc',
        'type'  => 'hard',
        'value' => '65536',
      },
      {
        'item'  => 'nofile',
        'type'  => 'soft',
        'value' => '8192',
      },
      {
        'item'  => 'nofile',
        'type'  => 'hard',
        'value' => '65536',
      },
    ],
  },
}
```

#### Parameters

The following parameters are available in the `limits::file` defined type:

* [`name`](#name)
* [`sequence`](#sequence)
* [`header_comment`](#header_comment)
* [`entries`](#entries)
* [`dir_limits`](#dir_limits)

##### <a name="name"></a>`name`

This will be combined with the sequence number to create the filename in
/etc/security/limits.d/
The name will have the form "${sequence}_${name}"

##### <a name="sequence"></a>`sequence`

Data type: `Pattern[/^[0-9]{2}$/]`

Two digit number used to build the filename.

##### <a name="header_comment"></a>`header_comment`

Data type: `Array[String]`

Array of strings which will be added to the header of the limit file on
creation.

##### <a name="entries"></a>`entries`

Data type: `Hash[String, Array[Limits::Entry]]`

Keys represent the user or group name for which the entries in the
associated  followed by various attributes which are to be set in the limits
file.

##### <a name="dir_limits"></a>`dir_limits`

Data type: `Stdlib::AbsolutePath`



Default value: `'/etc/security/limits.d'`

## Data types

### <a name="limitsentry"></a>`Limits::Entry`

Defines a limit entry for a specific domain

Alias of

```puppet
Struct[=>]
```

#### Parameters

The following parameters are available in the `Limits::Entry` data type:

* [`item`](#item)
* [`type`](#type)
* [`value`](#value)
* [`Optional`](#Optional)

##### <a name="item"></a>`item`

Particular item to limit. This is a fixed list see `man -s 5 limits.conf` for
detail.

##### <a name="type"></a>`type`

Specifies whether this value corresponds to soft, hard, or both types. If
both is specified two lines will be created in the resulting limits file.

##### <a name="value"></a>`value`

String representation of the limit value. Note that not all values are valid
for all limit entries. See `man -s 5 limits.conf` for details.

##### <a name="Optional"></a>`Optional`

Data type: `comment`

One or more lines which will be added before the particular entry line or
lines. If absent no comment lines are inserted.

### <a name="limitsfiledefinition"></a>`Limits::FileDefinition`

Defines a limit file containing one or more entries

Alias of

```puppet
Struct[=>]
```

#### Parameters

The following parameters are available in the `Limits::FileDefinition` data type:

* [`name`](#name)
* [`sequence`](#sequence)
* [`header_comment`](#header_comment)
* [`entries`](#entries)

##### <a name="name"></a>`name`

This will be combined with the sequence number to create the filename in
/etc/security/limits.d/
The name will have the form "${sequence}_${name}"

##### <a name="sequence"></a>`sequence`

Two digit number used to build the filename.

##### <a name="header_comment"></a>`header_comment`

Array of strings which will be added to the header of the limit file on
creation.

##### <a name="entries"></a>`entries`

Keys represent the user or group name for which the entries in the
associated  followed by various attributes which are to be set in the limits
file.

### <a name="limitsitem"></a>`Limits::Item`

List of valid items to specify in /etc/security/limits.conf

Alias of

```puppet
Enum['core', 'data', 'fsize', 'memlock', 'nofile', 'rss', 'stack', 'cpu', 'nproc', 'as', 'maxlogins', 'maxsyslogins', 'nonewprivs', 'priority', 'locks', 'sigpending', 'msgqueue', 'nice', 'rtprio']
```

